Charm for IBM WebSphere Application Server Network Deployment (WAS ND) 8.5.5.0

## Overview

IBM WebSphere Application Server Network Deployment provides an advanced, flexible runtime environment for large-scale application deployments. It offers near-continuous availability with advanced performance and management capabilities for mission-critical applications. For details on IBM Websphere Application Server Network Deployment,  as well as information on purchasing, please visit [Product Page][WAS-ND-product-page] and at the [Passport Advantage Site] [Passport-Advantage]. More information available at the [IBM Knowledge Center] [WAS-ND-Infocenter].

`IBM WebSphere Application Server Network Deployment`

This charm is used as a common layer for IBM WAS ND DM and IBM WAS ND Node charms to install IBM WAS ND Software. This charm is internally using ibm-im charm as a base layer to install Installation Manager tool for IBM WAS ND Software installation.

**Please note that the WAS ND charms (WAS ND, WAS ND DM and WAS ND Node) will create IBM WAS ND dynamic cluster.

## Prerequisites

This charm makes use of resources, a feature only available in Juju 2.0. During deploy or upgrade, you will need to specify the installable package(s) required by this charm. Download your licensed IBM WebSphere Application Server ND packages from the [Product Page][WAS-ND-8.5.5.0-download].

### Packages for Ubuntu on AMD64 (x86_64):

IBM Installation Manager 1.8 (`agent.installer.linux.gtk.x86_64_1.8.3000.20150606_0047.zip`)

IBM WAS ND 8.5.5 part1 (WASND_v8.5.5_1of3.zip)

IBM WAS ND 8.5.5 part2 (WASND_v8.5.5_2of3.zip)

IBM WAS ND 8.5.5 part3 (WASND_v8.5.5_3of3.zip)

### Packages for Ubuntu on Power (ppc64le):

IBM Installation Manager 1.8 (`agent.installer.linux.gtk.ppc64le_1.8.3000.20150606_0047.zip`)

IBM WAS ND 8.5.5 part1 (WAS_ND_V8.5.5_FOR_POWERLE_ML.zip)

IBM WAS ND 8.5.5 part2 (WASND_V8.5.5_2OF_2_FOR_POWERLE_ML.zip)

## Usage

To use this charm, you must agree to the Terms of Use. You can view the full license for `IBM Installation Manager` and `IBM WebSphere Application Server Network Deployment` products by visiting the [im-license-info](http://www-03.ibm.com/software/sla/sladb.nsf/displaylis/39AFC1C1D485C4E085257E7300548B05?OpenDocument) and [was-nd-license-info] [license-info] page.

Search for "IBM WebSphere Application Server Network Deployment" and choose the license that applies to the version you are using.


## Memory and Disk Requirements

Minimum 2.0 GB of disk space for installed image and Minimum 1 GB of physical memory recommended. 

WebSphere Application Server ND Charm requires 15 GB of root disk to download packages and install the IBM WebSphere Application Server ND Software. By default available root disk space is 8GB.

To request a larger root disk, run the following command:

		juju set-constraints root-disk=15G

### Deploy

Run the following commands to deploy this charm:

    juju deploy ibm-was-nd --resource ibm_im_installer=</path/to/ibm_im_installer.zip> --resource ibm_was_nd_installer1=</path/to/ibm_was_nd_installer1.zip> --resource ibm_was_nd_installer2=</path/to/ibm_was_nd_installer2.zip> --resource ibm_was_nd_installer3=</path/to/ibm_was_nd_installer3.zip>

**Note**: This charm requires acceptance of Terms of Use. When deploying from the Charm Store, these terms will be presented to you for your consideration.

To accept the terms:

    juju agree ibm-was-nd/1

** This charm can be deployed and tested. But it is useful when you use it as a layer with `IBM WAS ND DM` and `IBM WAS ND Node` charms.

This layer is intended to be extended by `IBM WAS ND DM` and `IBM WAS ND Node` charms that would install WAS ND software.
`IBM WAS ND DM` and `IBM WAS ND Node` layered charms could include this layer so it could install IBM WAS ND to configure deployment manager(DM) and Nodes to setup dynamic cluster. 

To use this layer, include the following in `layer.yaml`:

```yaml
includes: ['layer:ibm-was-nd']
```
## Reactive States

This layer charm will set the folowing state.

	`ibm-was-nd.installed` : This state will be set once WAS ND software is installed successfully. 

## IBM WebSphere Application Server Network Deployment Information

(1) General Information 

Details about IBM WAS ND software available at [IBM Knowledge Center] [WAS-ND-Infocenter].

Information on procuring WAS ND product is available at the [Passport Advantage site] [Passport-Advantage]

(2) Download Information

Details about WAS 8.5.5.0 download available [here] [[WAS-ND-8.5.5.0-download]

Information about installation of WAS ND on 'ppc64le' based machine available [here] [WAS-ND-for-ppc64le]  

More information about IBM IM Downloadable file and WAS ND downloadable files available [here] [IBM-IM-more-info]

## Contact Information

For issues with this charm, please contact IBM Juju Support team <jujusupp@us.ibm.com>

<!-- Links -->

[WAS-ND-Infocenter]: http://www-01.ibm.com/support/knowledgecenter/SSAW57_8.5.5/as_ditamaps/was855_welcome_ndmp.html?lang=en

[WAS-ND-product-page]: http://www-03.ibm.com/software/products/en/appserv-wasnd

[WAS-ND-8.5.5.0-download]: http://www-01.ibm.com/support/docview.wss?uid=swg27038624

[Passport-Advantage]: http://www-01.ibm.com/software/passportadvantage/

[IBM-IM-more-info]: http://www-01.ibm.com/support/docview.wss?uid=swg24038380

[WAS-ND-for-ppc64le]: http://www-304.ibm.com/support/knowledgecenter/SSEQTP_8.5.5/com.ibm.websphere.installation.nd.doc/ae/cins_offerings.html?lang=en-us

[WAS-ppc64le-fixpack-info]: http://www-01.ibm.com/support/docview.wss?uid=swg24040035

[license-info]: http://www-03.ibm.com/software/sla/sladb.nsf/lilookup/6CCA78CD870DCA5985257D90005A5351?OpenDocument